import os
import unittest

from parameterized import parameterized_class

from checkov.common.bridgecrew.check_type import CheckType
from checkov.common.bridgecrew.severities import Severities, BcSeverities
from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
from checkov.common.graph.db_connectors.rustworkx.rustworkx_db_connector import RustworkxConnector
from checkov.json_doc.runner import Runner
from checkov.runner_filter import RunnerFilter
from checkov.json_doc.registry import registry

@parameterized_class([
   {"db_connector": NetworkxConnector},
   {"db_connector": RustworkxConnector}
])
class TestRunnerValid(unittest.TestCase):

    def test_registry_has_type(self):
        self.assertEqual(registry.report_type, CheckType.JSON)

    def test_runner_object_failing_check(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "object", "fail")
        checks_dir = os.path.join(current_dir, "checks", "object")
        runner = Runner(db_connector=self.db_connector())
        checks = ["CKV_FOO_1", "CKV_FOO_2"]
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework='all', checks=checks)
        )
        self.assertEqual(len(report.failed_checks), 3)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(len(report.passed_checks), 2)
        self.assertEqual(report.skipped_checks, [])
        report.print_console()

    def test_runner_honors_enforcement_rules(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "object", "fail")
        checks_dir = os.path.join(current_dir, "checks", "object")
        runner = Runner(db_connector=self.db_connector())
        filter = RunnerFilter(framework=['json'], use_enforcement_rules=True)
        # this is not quite a true test, because the checks don't have severities. However, this shows that the check registry
        # passes the report type properly to RunnerFilter.should_run_check, and we have tests for that method
        filter.enforcement_rule_configs = {CheckType.JSON: Severities[BcSeverities.OFF]}
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=filter
        )
        self.assertEqual(len(report.failed_checks), 0)
        self.assertEqual(len(report.parsing_errors), 0)
        self.assertEqual(len(report.passed_checks), 0)
        self.assertEqual(len(report.skipped_checks), 0)
        report.print_console()

    def test_runner_object_passing_check(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "object", "pass")
        checks_dir = os.path.join(current_dir, "checks", "object")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework="all", checks=["CKV_FOO_1"]),
        )
        self.assertEqual(len(report.passed_checks), 1)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(report.failed_checks, [])
        self.assertEqual(report.skipped_checks, [])
        report.print_console()

    def test_runner_array_failing_check(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "array", "fail")
        checks_dir = os.path.join(current_dir, "checks", "array")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework='all', checks=["CKV_BARBAZ_1"])
        )
        self.assertEqual(len(report.failed_checks), 3)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(len(report.passed_checks), 1)
        self.assertEqual(report.skipped_checks, [])
        report.print_console()

    def test_runner_array_passing_check(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "array", "pass")
        checks_dir = os.path.join(current_dir, "checks", "array")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework="all", checks=["CKV_BARBAZ_1"]),
        )
        self.assertEqual(len(report.passed_checks), 2)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(report.failed_checks, [])
        self.assertEqual(report.skipped_checks, [])
        report.print_console()

    def test_runner_complex_failing_check(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "complex", "fail")
        checks_dir = os.path.join(current_dir, "checks", "complex")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework='all', checks=["CKV_COMPLEX_1"])
        )
        self.assertEqual(len(report.failed_checks), 1)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(report.passed_checks, [])
        self.assertEqual(report.skipped_checks, [])
        report.print_console()

    def test_runner_complex_passing_check(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "complex", "pass")
        checks_dir = os.path.join(current_dir, "checks", "complex")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework="all", checks=["CKV_COMPLEX_1"]),
        )
        self.assertEqual(len(report.passed_checks), 1)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(report.failed_checks, [])
        self.assertEqual(report.skipped_checks, [])
        report.print_console()

    def test_focused_result_configuration_no_evaluated_key(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "result_config")
        checks_dir = os.path.join(current_dir, "checks", "result_config")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework="all", checks=["CKV_RESULT_CONFIG_1"]),
        )
        self.assertEqual(len(report.passed_checks), 1)

        # file_line_range should cover the entire file range for empty evaluated_key path
        self.assertEqual(report.passed_checks[0].file_line_range, [1, 81])
        report.print_console()

    def test_focused_result_configuration_full_evaluated(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "result_config")
        checks_dir = os.path.join(current_dir, "checks", "result_config")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework="all", checks=["CKV_RESULT_CONFIG_2"]),
        )
        self.assertEqual(len(report.passed_checks), 1)

        # file_line_range should cover the object that the evaluated_key path points at
        self.assertEqual(report.passed_checks[0].file_line_range, [19, 24])
        report.print_console()

    def test_focused_result_configuration_partial_evaluated_key(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = os.path.join(current_dir, "resources", "result_config")
        checks_dir = os.path.join(current_dir, "checks", "result_config")
        runner = Runner(db_connector=self.db_connector())
        report = runner.run(
            root_folder=valid_dir_path,
            external_checks_dir=[checks_dir],
            runner_filter=RunnerFilter(framework="all", checks=["CKV_RESULT_CONFIG_3"]),
        )
        self.assertEqual(len(report.passed_checks), 1)

        # file_line_range should cover the parent object of the key that the evaluated_key path points at
        self.assertEqual(report.passed_checks[0].file_line_range, [17, 31])
        report.print_console()

    def test_get_result_configuration_for_list_type(self):
        entity_conf = [{'file_name': 'branch_protection_rules', 'org_complementary_metadata': {}, 'repo_complementary_metadata': {}}]
        evaluated_keys = ['data/organization/ipAllowListForInstalledAppsEnabledSetting']
        result_config = registry.get_result_configuration(evaluated_keys, entity_conf)
        self.assertEqual(result_config, entity_conf)

    def test_get_result_configuration_for_dict_type(self):
        entity_conf = {'required_pull_request_reviews': {'dismiss_stale_reviews': False}, 'CKV_METADATA': {'file_name': 'pass', 'org_complementary_metadata': {}, 'repo_complementary_metadata': {}}}
        evaluated_keys = ['required_pull_request_reviews/dismiss_stale_reviews']
        result_config = registry.get_result_configuration(evaluated_keys, entity_conf)
        self.assertEqual(result_config, {'dismiss_stale_reviews': False})





if __name__ == "__main__":
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.EKSSecretsEncryption import check
from checkov.common.models.enums import CheckResult


class TestEKSSecretsEncryption(unittest.TestCase):
    def test_failure(self):
        resource_conf = {'name': ['bad-eks'], 'role_arn': ['${var.role_arn}'], 'vpc_config': [{'subnet_ids': [[]], 'endpoint_public_access': [True]}], 'encryption_config': [{'provider': [{'key_arn': ['${var.key_arn}']}], 'resources': [[]]}]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_failure2(self):
        resource_conf = {'name': ['bad-eks2'], 'role_arn': ['${var.role_arn}'], 'vpc_config': [{'subnet_ids': [[]], 'endpoint_public_access': [True]}]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        resource_conf = {'name': ['good-eks2'], 'role_arn': ['${var.role_arn}'], 'vpc_config': [{'subnet_ids': [[]], 'endpoint_public_access': [True]}], 'encryption_config': [{'provider': [{'key_arn': ['${var.key_arn}']}], 'resources': [['secrets']]}]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



from collections import Counter
from pathlib import Path

from checkov.common.graph.graph_builder import CustomAttributes
from checkov.common.graph.graph_builder.graph_components.block_types import BlockType
from checkov.dockerfile.graph_builder.graph_components.resource_types import ResourceType
from checkov.dockerfile.graph_builder.local_graph import DockerfileLocalGraph
from checkov.dockerfile.runner import Runner
from checkov.dockerfile.utils import get_scannable_file_paths, get_files_definitions

RESOURCES_DIR = Path(__file__).parent.parent / "resources"


def test_build_graph():
    # given
    test_dir_path = RESOURCES_DIR / "expose_port"
    files_list = get_scannable_file_paths(root_folder=test_dir_path)
    definitions, _ = get_files_definitions(files_list)

    local_graph = DockerfileLocalGraph(definitions=definitions)

    # when
    local_graph.build_graph(render_variables=False)

    # then
    assert len(local_graph.vertices) == 16
    assert len(local_graph.edges) == 0

    assert len(local_graph.vertices_by_block_type[BlockType.RESOURCE]) == 16

    resource_type_counts = Counter(
        [vertex.attributes.get(CustomAttributes.RESOURCE_TYPE) for vertex in local_graph.vertices]
    )
    assert resource_type_counts == Counter(
        {
            ResourceType.FROM: 3,
            ResourceType.RUN: 3,
            ResourceType.EXPOSE: 3,
            ResourceType.CMD: 3,
            ResourceType.COPY: 2,
            ResourceType.WORKDIR: 1,
            ResourceType.HEALTHCHECK: 1,
        }
    )



from typing import List, Any

from checkov.cloudformation.checks.resource.base_resource_negative_value_check import BaseResourceNegativeValueCheck
from checkov.common.models.enums import CheckCategories


class DeprecatedLambdaRuntime(BaseResourceNegativeValueCheck):
    def __init__(self) -> None:
        name = "Ensure Lambda Runtime is not deprecated"
        id = "CKV_AWS_363"
        supported_resources = ['AWS::Lambda::Function', 'AWS::Serverless::Function']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "Properties/Runtime"

    def get_forbidden_values(self) -> List[Any]:
        # Source: https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html
        return ["dotnetcore3.1", "nodejs12.x", "python3.6", "python2.7", "dotnet5.0", "dotnetcore2.1", "ruby2.5",
                "nodejs10.x", "nodejs8.10", "nodejs4.3", "nodejs6.10", "dotnetcore1.0", "dotnetcore2.0",
                "nodejs4.3-edge", "nodejs", "java8", "python3.7", "go1.x", "provided", "ruby2.7", "nodejs14.x",
                "nodejs16.x", "python3.9", "dotnet7", "dotnet6"
                # , "nodejs18.x" # Uncomment on Sept 1, 2025
                # , "provided.al2" # Uncomment on Jun 30, 2026
                # , "python3.9" # Uncomment on Nov 3, 2025
                ]


check = DeprecatedLambdaRuntime()



from typing import Dict, Any, List
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.util.type_forcers import force_list
from checkov.common.util.oidc_utils import gh_abusable_claims, gh_repo_regex


class AzureGithubActionsOIDCTrustPolicy(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure Azure GitHub Actions OIDC trust policy is configured securely"
        id = "CKV_AZURE_249"
        supported_resources = [
            "azuread_application_federated_identity_credential",
        ]
        categories = (CheckCategories.IAM,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def validate_subject_claim(self, subject: str) -> bool:
        """Validates the subject claim for security concerns"""
        if not subject:
            return False

        # If no colons - invalid format for GitHub Actions claims
        if ":" not in subject:
            return False

        claim_parts = subject.split(":")

        # Check for wildcards in critical positions
        if claim_parts[0] == "*" or claim_parts[1] == "*":
            return False

        # Check for abusable claims
        if claim_parts[0] in gh_abusable_claims:
            return False

        # Validate repo format if repo claim is used
        if claim_parts[0] == "repo":
            if not gh_repo_regex.match(claim_parts[1]):
                return False

        return True

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        """Scans the configuration for Azure GitHub Actions OIDC trust policy"""
        try:
            condition = force_list(conf.get("subject", [None]))[0]
            if not condition:
                return CheckResult.FAILED

            # We should have colon delimited subject claim
            if ":" not in condition or condition == "*":
                return CheckResult.FAILED

            # At this point we know we have a colon delimited subject claim, so length should be at least 2
            split_condition = condition.split(":")

            # First check -> wildcards
            if "*" == split_condition[0] or "*" == split_condition[1]:
                return CheckResult.FAILED

            # Second check -> abusable claims
            if split_condition[0] in gh_abusable_claims:
                return CheckResult.FAILED

            # Third check -> repo format
            if split_condition[0] == "repo" and not gh_repo_regex.match(split_condition[1]):
                return CheckResult.FAILED

            return CheckResult.PASSED

        except Exception:
            return CheckResult.FAILED

    def get_evaluated_keys(self) -> List[str]:
        return ["identity_federation/subject", "subject"]


check = AzureGithubActionsOIDCTrustPolicy()



import os
from parameterized import parameterized_class

from tests.graph_utils.utils import PARAMETERIZED_GRAPH_FRAMEWORKS
from tests.terraform.graph.checks_infra.test_base import TestBaseSolver

TEST_DIRNAME = os.path.dirname(os.path.realpath(__file__))

@parameterized_class(PARAMETERIZED_GRAPH_FRAMEWORKS)
class ExistsSolver(TestBaseSolver):
    def setUp(self):
        self.checks_dir = TEST_DIRNAME
        super(ExistsSolver, self).setUp()

    def test_nested_attribute_exists(self):
        root_folder = '../../../resources/s3_bucket'
        check_id = "VersioningEnabledExists"
        should_pass = ['aws_s3_bucket.destination']
        should_fail = []
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_nested_attribute_doesnt_exists(self):
        root_folder = '../../../resources/s3_bucket'
        check_id = "TagEnvironmentExists"
        should_pass = []
        should_fail = ['aws_s3_bucket.destination']
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_all_resources(self):
        root_folder = '../../../resources/encryption_test'
        check_id = "TagEnvironmentExistsAll"
        should_pass = []
        should_fail = ["aws_rds_cluster.rds_cluster_encrypted", "aws_rds_cluster.rds_cluster_unencrypted",
                       "aws_s3_bucket.encrypted_bucket", "aws_s3_bucket.unencrypted_bucket",
                       "aws_neptune_cluster.encrypted_neptune", "aws_neptune_cluster.unencrypted_neptune"]
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)



import unittest

import hcl2

from checkov.terraform.checks.resource.azure.AzureDataExplorerDoubleEncryptionEnabled import check
from checkov.common.models.enums import CheckResult


class TestAzureDataExplorerDoubleEncryptionEnabled(unittest.TestCase):

    def test_failure1(self):
        hcl_res = hcl2.loads("""
            resource "azurerm_kusto_cluster" "example" {
              name                = "kustocluster"
              location            = azurerm_resource_group.rg.location
              resource_group_name = azurerm_resource_group.rg.name
            
              sku {
                name     = "Standard_D13_v2"
                capacity = 2
              }
            
              tags = {
                Environment = "Production"
              }
            }
                """)
        resource_conf = hcl_res['resource'][0]['azurerm_kusto_cluster']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_failure2(self):
        hcl_res = hcl2.loads("""
                resource "azurerm_kusto_cluster" "example" {
                  name                = "kustocluster"
                  location            = azurerm_resource_group.rg.location
                  resource_group_name = azurerm_resource_group.rg.name
                  double_encryption_enabled = false
                
                  sku {
                    name     = "Standard_D13_v2"
                    capacity = 2
                  }
                
                  tags = {
                    Environment = "Production"
                  }
                }
                """)
        resource_conf = hcl_res['resource'][0]['azurerm_kusto_cluster']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        hcl_res = hcl2.loads("""
                resource "azurerm_kusto_cluster" "example" {
                  name                = "kustocluster"
                  location            = azurerm_resource_group.rg.location
                  resource_group_name = azurerm_resource_group.rg.name

                  sku {
                    name     = "Standard_D13_v2"
                    capacity = 2
                  }
                  
                  double_encryption_enabled = true

                  tags = {
                    Environment = "Production"
                  }
                }
                """)
        resource_conf = hcl_res['resource'][0]['azurerm_kusto_cluster']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



from aws_cdk import core
from aws_cdk import aws_ecs as ecs

class MyECSTaskDefinitionStack(core.Stack):
    def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
        super().__init__(scope, id, **kwargs)

        # Define ECS Task Definition with an EFS volume configuration and transit encryption disabled
        task_definition = ecs.CfnTaskDefinition(
            self, 'MyTaskDefinition',
            volumes=[
                {
                    'efs_volume_configuration': {
                        'transit_encryption': 'ENABLED'
                    }
                }
            ]
            # Other properties for your ECS Task Definition
        )

app = core.App()
MyECSTaskDefinitionStack(app, "MyECSTaskDefinitionStack")
app.synth()



import os

from checkov.common.checks_infra.solvers.attribute_solvers.greater_than_attribute_solver import \
    GreaterThanAttributeSolver
from checkov.common.checks_infra.solvers.attribute_solvers.greater_than_or_equal_attribute_solver import \
    GreaterThanOrEqualAttributeSolver
from checkov.common.checks_infra.solvers.attribute_solvers.less_than_attribute_solver import LessThanAttributeSolver
from checkov.common.checks_infra.solvers.attribute_solvers.less_than_or_equal_attribute_solver import \
    LessThanOrEqualAttributeSolver
from tests.graph_utils.utils import PARAMETERIZED_GRAPH_FRAMEWORKS
from tests.terraform.graph.checks_infra.test_base import TestBaseSolver
from parameterized import parameterized_class

TEST_DIRNAME = os.path.dirname(os.path.realpath(__file__))

@parameterized_class(PARAMETERIZED_GRAPH_FRAMEWORKS)
class TestGreaterThanLessThanSolvers(TestBaseSolver):
    def setUp(self):
        self.checks_dir = TEST_DIRNAME
        super(TestGreaterThanLessThanSolvers, self).setUp()

    def test_greater_than_solver_simple(self):
        # this is just a basic check to make sure the operator works
        # we'll check all the other combinations more directly (because coming up with all the policy combos is painful)
        root_folder = 'resources'
        check_id = "GT"
        should_pass = ['aws_s3_bucket.b2']
        should_fail = ['aws_s3_bucket.b1', 'aws_s3_bucket.b3']
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_less_than_solver_simple(self):
        root_folder = 'resources'
        check_id = "LT"
        should_pass = ['aws_s3_bucket.b1']
        should_fail = ['aws_s3_bucket.b2', 'aws_s3_bucket.b3']
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_greater_than_or_equal_solver_simple(self):
        # this is just a basic check to make sure the operator works
        # we'll check all the other combinations more directly (because coming up with all the policy combos is painful)
        root_folder = 'resources'
        check_id = "GTE"
        should_pass = ['aws_s3_bucket.b2', 'aws_s3_bucket.b3']
        should_fail = ['aws_s3_bucket.b1']
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_less_than_or_equal_solver_simple(self):
        root_folder = 'resources'
        check_id = "LTE"
        should_pass = ['aws_s3_bucket.b1', 'aws_s3_bucket.b3']
        should_fail = ['aws_s3_bucket.b2']
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_greater_than_solver_unrendered(self):
        root_folder = '../../../resources/variable_rendering/unrendered'
        check_id = "GT"
        should_pass = []
        should_fail = []
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_less_than_solver_unrendered(self):
        root_folder = '../../../resources/variable_rendering/unrendered'
        check_id = "LT"
        should_pass = []
        should_fail = []
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_greater_than_or_equal_solver_unrendered(self):
        root_folder = '../../../resources/variable_rendering/unrendered'
        check_id = "GTE"
        should_pass = []
        should_fail = []
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_less_than_or_equal_solver_unrendered(self):
        root_folder = '../../../resources/variable_rendering/unrendered'
        check_id = "LTE"
        should_pass = []
        should_fail = []
        expected_results = {check_id: {"should_pass": should_pass, "should_fail": should_fail}}

        self.run_test(root_folder=root_folder, expected_results=expected_results, check_id=check_id)

    def test_gt_combinations(self):
        cls = GreaterThanAttributeSolver

        self.assertTrue(cls([], None, 1)._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 1)._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 1)._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '1.5', 'source_': 'Terraform'}, 'a'))

        self.assertFalse(cls([], None, 1)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 1)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1.0')._get_operation({'a': '1.0', 'source_': 'Terraform'}, 'a'))

        self.assertFalse(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 2)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '2')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '2')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 'xxxx')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 'xxxx')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 'xxxx')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))

        # undefined types
        self.assertTrue(cls([], None, '1')._get_operation({'a': {'abc': 'xyz'}, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, {'a': {'abc': 'xyz'}})._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': ['xyz'], 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, ['xyz'])._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))

        # attr not exists
        self.assertFalse(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'b'))

        # unrendered variable
        self.assertTrue(cls([], None, '1')._get_operation({'a': 'var.x', 'source_': 'Terraform'}, 'a'))

    def test_gte_combinations(self):
        cls = GreaterThanOrEqualAttributeSolver

        self.assertTrue(cls([], None, 1)._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 1)._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 1)._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '1.5', 'source_': 'Terraform'}, 'a'))

        self.assertTrue(cls([], None, 1)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 1)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '1.0', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1.0')._get_operation({'a': '1.0', 'source_': 'Terraform'}, 'a'))

        self.assertFalse(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 2)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '2')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '2')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 'xxxx')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 'xxxx')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 'xxxx')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))

        # undefined types
        self.assertTrue(cls([], None, '1')._get_operation({'a': {'abc': 'xyz'}, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, {'a': {'abc': 'xyz'}})._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': ['xyz'], 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, ['xyz'])._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))

        # attr not exists
        self.assertFalse(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'b'))

        # unrendered variable
        self.assertTrue(cls([], None, '1')._get_operation({'a': 'var.x', 'source_': 'Terraform'}, 'a'))

    def test_lt_combinations(self):
        cls = LessThanAttributeSolver

        self.assertFalse(cls([], None, 1)._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 1)._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 1)._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': '1.5', 'source_': 'Terraform'}, 'a'))

        self.assertFalse(cls([], None, 1)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 1)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1.0')._get_operation({'a': '1.0', 'source_': 'Terraform'}, 'a'))

        self.assertTrue(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 2)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '2')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '2')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 'xxxx')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 'xxxx')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 'xxxx')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))

        # undefined types
        self.assertFalse(cls([], None, '1')._get_operation({'a': {'abc': 'xyz'}, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, {'a': {'abc': 'xyz'}})._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': ['xyz'], 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, ['xyz'])._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))

        # attr not exists
        self.assertFalse(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'b'))

        # unrendered variable
        self.assertIsNone(cls([], 'a', '1').get_operation({'a': 'var.x', 'source_': 'Terraform'}))

    def test_lte_combinations(self):
        cls = LessThanOrEqualAttributeSolver

        self.assertFalse(cls([], None, 1)._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 1)._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': 2, 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': '2', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, 1)._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': '1.5', 'source_': 'Terraform'}, 'a'))

        self.assertTrue(cls([], None, 1)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 1)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '1.0')._get_operation({'a': '1.0', 'source_': 'Terraform'}, 'a'))

        self.assertTrue(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 2)._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '2')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, '2')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 'xxxx')._get_operation({'a': 'aaa', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 'xxxx')._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, 'xxxx')._get_operation({'a': 1, 'source_': 'Terraform'}, 'a'))

        self.assertFalse(cls([], None, '1')._get_operation({'a': {'abc': 'xyz'}, 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, {'a': {'abc': 'xyz'}})._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))
        self.assertFalse(cls([], None, '1')._get_operation({'a': ['xyz'], 'source_': 'Terraform'}, 'a'))
        self.assertTrue(cls([], None, ['xyz'])._get_operation({'a': '1', 'source_': 'Terraform'}, 'a'))

        # attr not exists
        self.assertFalse(cls([], None, 2)._get_operation({'a': 1, 'source_': 'Terraform'}, 'b'))

        # unrendered variable
        self.assertIsNone(cls([], 'a', '1').get_operation({'a': 'var.x', 'source_': 'Terraform'}))



from aws_cdk import core
from aws_cdk import aws_apigateway as apigateway
from aws_cdk import aws_apigatewayv2 as apigatewayv2

class MyApiGatewayStageStack(core.Stack):
    def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
        super().__init__(scope, id, **kwargs)

        # Define API Gateway Stage with Tracing Enabled
        apigateway.CfnStage(
            self, 'MyApiGatewayStage',
            stage_name='my-stage',
            rest_api_id='your-rest-api-id',  # Replace with your RestApi Id
            tracing_enabled=False
            # Other properties for your API Gateway Stage
        )

app = core.App()
MyApiGatewayStageStack(app, "MyApiGatewayStageStack")
app.synth()

class MyServerlessApiStack(core.Stack):
    def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
        super().__init__(scope, id, **kwargs)

        # Define Serverless API with Tracing Enabled
        api = apigatewayv2.CfnApi(
            self, 'MyServerlessApi',
            name='my-serverless-api',
            protocol_type='HTTP'
            # Other properties for your Serverless API
        )

        stage = apigatewayv2.CfnStage(
            self, 'MyServerlessApiStage',
            api_id=api.ref,
            stage_name='my-stage',
            tracing_enabled=False
            # Other properties for your API Gatewayv2 Stage
        )

app = core.App()
MyServerlessApiStack(app, "MyServerlessApiStack")
app.synth()


from typing import Any, Dict
import re

from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories, CheckResult

_SECURE_RE = re.compile(r"^TLSv1\.(?:2|3)_\d{4}$")


class CloudFrontTLS12(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Verify CloudFront Distribution Viewer Certificate is using TLS v1.2 or higher"
        id = "CKV_AWS_174"
        supported_resources = ["AWS::CloudFront::Distribution"]
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "Properties/DistributionConfig/ViewerCertificate/MinimumProtocolVersion"

    @staticmethod
    def validate_value(value: Any) -> bool:
        return isinstance(value, str) and bool(_SECURE_RE.match(value))

    def get_evaluated_keys(self):
        return [self.get_inspected_key()]

    def scan_resource_conf(self, conf: Dict[str, Any]) -> CheckResult:
        # Navigate CFN structure safely
        props = conf.get("Properties")
        if not isinstance(props, dict):
            return CheckResult.FAILED

        dist_cfg = props.get("DistributionConfig")
        if not isinstance(dist_cfg, dict):
            return CheckResult.FAILED

        viewer_cert = dist_cfg.get("ViewerCertificate")
        if not isinstance(viewer_cert, dict):
            return CheckResult.FAILED

        # If they use the CloudFront default cert, you can't set a secure policy -> fail explicitly
        if viewer_cert.get("CloudFrontDefaultCertificate") is True:
            return CheckResult.FAILED

        mpv = viewer_cert.get("MinimumProtocolVersion")
        if isinstance(mpv, str) and _SECURE_RE.match(mpv):
            return CheckResult.PASSED

        return CheckResult.FAILED


check = CloudFrontTLS12()



import unittest

import hcl2

from checkov.terraform.checks.resource.azure.PostgressSQLGeoBackupEnabled import check
from checkov.common.models.enums import CheckResult


class TestPostgressSQLGeoBackupEnabled(unittest.TestCase):

    def test_failure_1(self):
        hcl_res = hcl2.loads("""
            resource "azurerm_postgresql_server" "example" {
              name                = "example-psqlserver"
              location            = azurerm_resource_group.example.location
              resource_group_name = azurerm_resource_group.example.name
            
              administrator_login          = "psqladminun"
              administrator_login_password = "H@Sh1CoR3!"  # checkov:skip=CKV_SECRET_80 test secret
            
              sku_name   = "GP_Gen5_4"
              version    = "9.6"
              storage_mb = 640000
            
              backup_retention_days        = 7
              geo_redundant_backup_enabled = false
              auto_grow_enabled            = true

              public_network_access_enabled    = true
              ssl_enforcement_enabled          = true
              ssl_minimal_tls_version_enforced = "TLS1_2"
            }
        """)
        resource_conf = hcl_res['resource'][0]['azurerm_postgresql_server']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_failure_2(self):
        hcl_res = hcl2.loads("""
            resource "azurerm_postgresql_server" "example" {
              name                = "example-psqlserver"
              location            = azurerm_resource_group.example.location
              resource_group_name = azurerm_resource_group.example.name

              administrator_login          = "psqladminun"
              administrator_login_password = "H@Sh1CoR3!"

              sku_name   = "GP_Gen5_4"
              version    = "9.6"
              storage_mb = 640000

              backup_retention_days        = 7
              auto_grow_enabled            = true
              ssl_enforcement_enabled          = true
              ssl_minimal_tls_version_enforced = "TLS1_2"
            }
                """)
        resource_conf = hcl_res['resource'][0]['azurerm_postgresql_server']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        hcl_res = hcl2.loads("""
            resource "azurerm_postgresql_server" "example" {
              name                = "example-psqlserver"
              location            = azurerm_resource_group.example.location
              resource_group_name = azurerm_resource_group.example.name

              administrator_login          = "psqladminun"
              administrator_login_password = "H@Sh1CoR3!"

              sku_name   = "GP_Gen5_4"
              version    = "9.6"
              storage_mb = 640000

              backup_retention_days        = 7
              geo_redundant_backup_enabled = true
              auto_grow_enabled            = true

              public_network_access_enabled    = false
              ssl_enforcement_enabled          = true
              ssl_minimal_tls_version_enforced = "TLS1_2"
            }
                """)
        resource_conf = hcl_res['resource'][0]['azurerm_postgresql_server']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



import argparse
import unittest
import xml
import xml.etree.ElementTree as ET
from pathlib import Path

from checkov.common.models.enums import CheckResult
from checkov.common.output.report import Report
from checkov.common.output.record import Record
from checkov.runner_filter import RunnerFilter
from checkov.terraform.runner import Runner as TerrafomrRunner


class TestJunitReport(unittest.TestCase):
    def test_valid_passing_valid_testcases(self):
        record1 = Record(
            check_id="CKV_AWS_21",
            check_name="Some Check",
            check_result={"result": CheckResult.FAILED},
            code_block=[],
            file_path="./s3.tf",
            file_line_range=[1, 3],
            resource="aws_s3_bucket.operations",
            evaluations=None,
            check_class="",
            file_abs_path=",.",
            entity_tags={"tag1": "value1"},
        )
        record2 = Record(
            check_id="CKV_AWS_3",
            check_name="Ensure all data stored in the EBS is securely encrypted",
            check_result={"result": CheckResult.FAILED},
            code_block=[],
            file_path="./ec2.tf",
            file_line_range=[1, 3],
            resource="aws_ebs_volume.web_host_storage",
            evaluations=None,
            check_class="",
            file_abs_path=",.",
            entity_tags={"tag1": "value1"},
        )

        r = Report("terraform")
        r.add_record(record=record1)
        r.add_record(record=record2)
        ts = r.get_test_suite()
        xml_string = r.get_junit_xml_string([ts])
        root = ET.fromstring(xml_string)
        self.assertEqual(root.attrib["errors"], "0")

    def test_get_junit_xml_string_with_terraform(self):
        # given
        test_file = Path(__file__).parent / "fixtures/main.tf"
        checks = ["CKV_AWS_18", "CKV_AWS_19", "CKV_AWS_21"]  # 1 pass, 1 fail, 1 skip
        config = argparse.Namespace(file="fixtures/main.tf", framework=["terraform"])
        report = TerrafomrRunner().run(
            root_folder="", files=[str(test_file)], runner_filter=RunnerFilter(checks=checks)
        )

        # remove guideline from failed checks, if they were fetched before
        for check in report.failed_checks:
            check.guideline = None

        # then
        properties = Report.create_test_suite_properties_block(config=config)
        test_suite = report.get_test_suite(properties=properties)
        xml_string = Report.get_junit_xml_string([test_suite])

        # then
        assert (
            xml.dom.minidom.parseString(xml_string).toprettyxml()
            == xml.dom.minidom.parseString(
                "".join(
                    [
                        '<?xml version="1.0" ?>\n',
                        '<testsuites disabled="0" errors="0" failures="1" tests="2" time="0.0">\n',
                        '\t<testsuite disabled="0" errors="0" failures="1" name="terraform scan" skipped="1" tests="2" time="0">\n',
                        "\t\t<properties>\n",
                        '\t\t\t<property name="file" value="fixtures/main.tf"/>\n',
                        '\t\t\t<property name="framework" value="[\'terraform\']"/>\n',
                        "\t\t</properties>\n",
                        '\t\t<testcase name="[NONE][CKV_AWS_18] Ensure the S3 bucket has access logging enabled" classname="/main.tf.aws_s3_bucket.destination" file="/main.tf">\n',
                        '\t\t\t<failure type="failure" message="Ensure the S3 bucket has access logging enabled">\n',
                        "Resource: aws_s3_bucket.destination\n",
                        "File: /main.tf: 1-8\n",
                        "Guideline: None\n",
                        "\n",
                        "\t\t1 | resource &quot;aws_s3_bucket&quot; &quot;destination&quot; {\n",
                        "\t\t2 |   # checkov:skip=CKV_AWS_19: no encryption needed\n",
                        "\t\t3 |   bucket = &quot;tf-test-bucket-destination-12345&quot;\n",
                        "\t\t4 |   acl = var.acl\n",
                        "\t\t5 |   versioning {\n",
                        "\t\t6 |     enabled = var.is_enabled\n",
                        "\t\t7 |   }\n",
                        "\t\t8 | }</failure>\n",
                        "\t\t</testcase>\n",
                        '\t\t<testcase name="[NONE][CKV_AWS_19] Ensure all data stored in the S3 bucket is securely encrypted at rest" classname="/main.tf.aws_s3_bucket.destination" file="/main.tf">\n',
                        '\t\t\t<skipped type="skipped" message=" no encryption needed"/>\n',
                        "\t\t</testcase>\n",
                        "\t</testsuite>\n",
                        "</testsuites>\n",
                    ]
                )
            ).toprettyxml()
        )

    def test_sensitive_properties_excluded_from_junit_xml(self):
        # given
        test_file = Path(__file__).parent / "fixtures/main.tf"
        checks = ["CKV_AWS_18"]  # Just need one check for this test

        # Create config with a sensitive property (bc_api_key)
        config = argparse.Namespace(
            file="fixtures/main.tf",
            framework=["terraform"],
            bc_api_key="secret_api_key_123",  # checkov:skip=CKV_SECRET_6 test secret # This should be excluded
            non_sensitive_prop="regular_value"  # This should be included
        )

        report = TerrafomrRunner().run(
            root_folder="", files=[str(test_file)], runner_filter=RunnerFilter(checks=checks)
        )

        properties = Report.create_test_suite_properties_block(config=config)
        test_suite = report.get_test_suite(properties=properties)
        xml_string = Report.get_junit_xml_string([test_suite])
        root = ET.fromstring(xml_string)
        testsuite = root.find('testsuite')
        props = testsuite.find('properties')

        # Check that sensitive properties are not included
        property_names = [prop.attrib['name'] for prop in props.findall('property')]
        self.assertIn('file', property_names, "Expected 'file' property to be present")
        self.assertIn('framework', property_names, "Expected 'framework' property to be present")
        self.assertIn('non_sensitive_prop', property_names, "Expected 'non_sensitive_prop' property to be present")

        # Most important assertions - check that sensitive properties are excluded
        self.assertNotIn('bc_api_key', property_names, "Sensitive property 'bc_api_key' should be excluded")

        # Double check the XML string itself doesn't contain the sensitive values
        self.assertNotIn('secret_api_key_123', xml_string, "API key value should not appear in XML")


if __name__ == "__main__":
    unittest.main()



from __future__ import annotations

import re
from typing import Any

from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.common.util.secrets import AWS, GENERAL, PASSWORD, get_secrets_from_string


class ParameterStoreCredentials(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure no hard-coded secrets exist in Parameter Store values"
        id = "CKV_AWS_384"
        supported_resources = ("AWS::SSM::Parameter",)
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def is_dynamic_value(self, value: str) -> bool:
        patterns = [
            r"\$\{.*?\}",  # ${...}
            r"\{\{.*?\}\}",  # {{...}}
            r"\$\(.*?\)",  # $(...)
            r"!Ref\s+\w+",  # !Ref SomeResource
            r"!Sub\s+'.*?'",  # !Sub '...'
        ]
        return any(re.search(pattern, value) for pattern in patterns)

    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
        self.evaluated_keys = ["Properties/Value"]
        properties = conf.get("Properties")
        if isinstance(properties, dict):
            name = properties.get("Name")
            if name and re.match("(?i).*secret.*|.*api_?key.*", str(name)):
                value = properties.get("Value")
                if value:
                    # If unresolved variable, then pass
                    if isinstance(value, dict):
                        return CheckResult.PASSED
                    # If unresolved variable, then pass 2
                    if re.match(r".*\$\{.*}.*", value):
                        return CheckResult.PASSED
                    if (re.match("(?i)(.*test.*|.*example.*)", name) or
                            re.match("(?i)(.*test.*|.*example.*)", value)):
                        return CheckResult.PASSED
                    secret = get_secrets_from_string(str(value), AWS, GENERAL, PASSWORD)
                    if secret:
                        return CheckResult.FAILED
        return CheckResult.PASSED


check = ParameterStoreCredentials()



from __future__ import annotations

from checkov.common.sast.consts import SastLanguages
from checkov.sast.engines.prisma_engine import PrismaEngine
from checkov.sast.record import SastRecord
from checkov.sast.report import SastData, SastReport
from checkov.common.sast.report_types import Function, PrismaReport, Repositories, File, Package, Point, MatchLocation, \
    DataFlow, MatchMetadata, RuleMatch, Match, SkippedCheck, RuleMatchMetadata


def _create_sast_reports_for_test_get_sast_reachability_report_with_one_report() -> list[SastReport]:
    # we don't care about the init's params, except for the sast-language
    report1 = SastReport('', {}, SastLanguages.JAVASCRIPT, PrismaReport(rule_match={}, errors={}, profiler={},
                                                                        run_metadata={}, imports={},
                                                                        reachability_report={},
                                                                        skipped_checks_by_file={}))
    report1.sast_reachability = {
        'repo_1': Repositories(files={
            '/index.js': File(packages={
                'axios': Package(alias='ax', functions=[
                    Function(name='trim', alias='hopa', line_number=4, code_block='hopa()', cve_id='cve-11')
                ]),
                'lodash': Package(alias='', functions=[
                    Function(name='template', alias='', line_number=1, code_block='template()', cve_id='cve-11'),
                    Function(name='toNumber', alias='', line_number=4, code_block='hopa()', cve_id='cve-11')
                ])
            }),
            '/main.js': File(packages={
                'axios': Package(alias='ax', functions=[
                    Function(name='trim', alias='hi', line_number=4, code_block='hi()', cve_id='cve-11')
                ])
            })
        })
    }
    return [report1]


def test_get_sast_reachability_report_with_one_report():
    scan_reports: list[SastReport] = _create_sast_reports_for_test_get_sast_reachability_report_with_one_report()
    sast_reachability_report = SastData.get_sast_reachability_report(scan_reports)
    assert sast_reachability_report == {
        'reachability': {
            SastLanguages.JAVASCRIPT: {
                '/index.js': File(packages={
                    'axios': Package(alias='ax', functions=[
                        Function(name='trim', alias='hopa', line_number=4, code_block='hopa()', cve_id='cve-11')
                    ]),
                    'lodash': Package(alias='', functions=[
                        Function(name='template', alias='', line_number=1, code_block='template()', cve_id='cve-11'),
                        Function(name='toNumber', alias='', line_number=4, code_block='hopa()', cve_id='cve-11')
                    ])
                }),
                '/main.js': File(packages={
                    'axios': Package(alias='ax', functions=[
                        Function(name='trim', alias='hi', line_number=4, code_block='hi()', cve_id='cve-11')
                    ])
                })
            }
        }
    }


def test_get_code_lines_taint():
    record = SastRecord(check_id='', check_name='', resource='', evaluations={},
                        check_class='', check_result=None, code_block=[], file_path='', file_line_range=[],
                        metadata=MatchMetadata(taint_mode=DataFlow(data_flow=[MatchLocation(path='checkov/arosenfeld6666/arosenfeld6666_abc/aaa/1706717499988/src/file_that_import.js', start=Point(row=3, column=0), end=Point(row=3, column=32), code_block='let password = request.password;'), MatchLocation(path='checkov/arosenfeld6666/arosenfeld6666_abc/aaa/1706717499988/src/file_that_import.js', start=Point(row=6, column=0), end=Point(row=6, column=17), code_block='Danger(password);'), MatchLocation(path='checkov/arosenfeld6666/arosenfeld6666_abc/aaa/1706717499988/src/imported_file.js', start=Point(row=2, column=4), end=Point(row=2, column=38), code_block='console.log("Danger: " + password)')])),
                        file_abs_path='', severity=None, cwe='',
                        owasp='', show_severity=True)

    code_lines_actual_output, file_details_actual_output = record.get_code_lines_taint(record.metadata.taint_mode.data_flow)
    code_lines_expected_output = '\t\tfile_that_import.js\n\t\t\x1b[37m3 | \x1b[33mlet password = request.password;\n\t\t...\n\t\t\x1b[37m6 | \x1b[33mDanger(password);\n\t\timported_file.js\n\t\t\x1b[37m2 | \x1b[33mconsole.log("Danger: " + password)\n'
    file_details_expected_output = 'file_that_import.js->3->6->imported_file.js->2'
    assert code_lines_expected_output == code_lines_actual_output
    assert file_details_expected_output == file_details_actual_output


def test_skipped_checks():
    report = PrismaReport(rule_match={
        SastLanguages.PYTHON: {'CKV3_SAST_11': RuleMatch(
            check_id='CKV3_SAST_11', check_name='Use of module setting superuser port',
            check_cwe=['CWE-289: Authentication Bypass by Alternate Name'], severity='LOW', check_owasp=None,
            metadata=RuleMatchMetadata(), matches=[
                Match(exact_hash='e97a01a1cb2abee84ad113d828f8d500eccb150941200fd6df9356bb9c193604',
                      structure_hash='8e63ba7c140643381a68470a5d9296e6290999e3fc70971e860480c0bc24a474',
                      location=MatchLocation(
                          path='tests/python/src/simple_within.py',
                          start=Point(row=2, column=0), end=Point(row=2, column=11), code_block='set_port(1)'),
                      metadata=MatchMetadata(taint_mode=None, code_locations=None),
                      minimized_ast='{"type":"module","children":[{"type":"expression_statement","children":[{"type":"call","name":"set_port","children":[{"type":"identifier"},{"type":"argument_list","children":[{"type":"integer"}]}]}]}]}')])}
    }, errors={}, profiler={}, run_metadata={}, imports={}, reachability_report={}, skipped_checks_by_file={
        'tests/python/src/simple_within.py': [SkippedCheck(check_id='CKV3_SAST_11', suppress_comment="Don't feel like it")]
    })
    prisma_engine = PrismaEngine()
    prisma_engine.enable_inline_suppressions = True
    sast_report = prisma_engine.create_report(report)
    assert len(sast_report[0].failed_checks) == 0 and len(sast_report[0].skipped_checks) == 1
    assert sast_report[0].skipped_checks[0].check_result['suppress_comment'] == "Don't feel like it"



from pathlib import Path
from typing import Any

from boolean import BooleanAlgebra, Expression as LicenseExpression

class Licensing(BooleanAlgebra):
    def parse(
        self,
        expression: bytes | str | LicenseExpression | None,
        validate: bool = ...,
        strict: bool = ...,
        simple: bool = ...,
        **kwargs: Any,
    ) -> LicenseExpression | None: ...

def get_spdx_licensing(license_index_location: str | Path = ...) -> Licensing: ...



import time
import unittest
from pathlib import Path

from detect_secrets.util.code_snippet import CodeSnippet
from detect_secrets.util.filetype import FileType

from checkov.runner_filter import RunnerFilter
from checkov.secrets.plugins.entropy_keyword_combinator import EntropyKeywordCombinator
from checkov.secrets.plugins.entropy_keyword_combinator import REGEX_VALUE_KEYWORD_BY_FILETYPE
from checkov.secrets.plugins.entropy_keyword_combinator import REGEX_VALUE_SECRET_BY_FILETYPE
from checkov.secrets.runner import Runner
from tests.secrets.utils_for_test import _filter_reports_for_incident_ids


class TestCombinatorPluginMultilineYml(unittest.TestCase):
    def setUp(self) -> None:
        self.plugin = EntropyKeywordCombinator()

    def test_keyword_in_value_pair(self):
        # first line is keyword, next line (underneath) is password
        context = CodeSnippet(
            snippet=[
                'name: "TEST_SOMETHING"',
                'value: "not-a-real-password"',
                'name: "TEST_PASSWORD_1"',
                'value: "Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE=="',
                'name: "TEST_PASSWORD_2"',
                'value: "Zmlyc3Rfc2VjcmV0MjIyMjIyX2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzI"',
                'name: "TEST_PASSWORD_3"',
                'value: "Z2FlYnJzZGhqa2p1aGdmZHN3cXdnaHluanVraWxvaWtqdWh5Z3RyZmVkd3NlcnR5dWk4bw"',
                'name: "TEST_PASSWORD_4"',
                'value: "Z2FlYnJzZGhqa2p1aGdmZHN3cXdnaHluanVraWxvaWtqdWh5Z3RyZmVkd3NlcnR5dWk4bw"',
                'name: "TEST_PASSWORD_BASE64_LONG_1"'
            ],
            start_line=112,
            target_index=5
        )
        raw_context = CodeSnippet(
            snippet=[
                '        - name: TEST_SOMETHING\n',
                '          value: not-a-real-password\n',
                '        - name: TEST_PASSWORD_1\n',
                '          value: Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==\n',
                '        - name: TEST_PASSWORD_2\n',
                '          value: Zmlyc3Rfc2VjcmV0MjIyMjIyX2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzI\n',
                '        - name: TEST_PASSWORD_3\n',
                '          value: Z2FlYnJzZGhqa2p1aGdmZHN3cXdnaHluanVraWxvaWtqdWh5Z3RyZmVkd3NlcnR5dWk4bw\n',
                '        - name: TEST_PASSWORD_4\n',
                '          value: Z2FlYnJzZGhqa2p1aGdmZHN3cXdnaHluanVraWxvaWtqdWh5Z3RyZmVkd3NlcnR5dWk4bw\n',
                '        - name: TEST_PASSWORD_LONG\n'
            ],
            start_line=112,
            target_index=5
        )
        res = self.plugin.analyze_line(
            filename="test.yml",
            line='value: "Zmlyc3Rfc2VjcmV0MjIyMjIyX2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzI"',
            line_number=118,
            context=context,
            raw_context=raw_context
        )
        expected_secret_value = 'Zmlyc3Rfc2VjcmV0MjIyMjIyX2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzI'
        assert res
        po_secret = res.pop()
        assert expected_secret_value == po_secret.secret_value
        assert po_secret.is_multiline is True

    def test_keyword_in_value_pair2(self):
        # first line is password, next line underneath is keyword
        context = CodeSnippet(
            snippet=[
                '',
                '',
                '',
                '',
                '',
                'value: "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"',
                'name: "TEST_PASSWORD_1"',
                'name1: "TEST_PASSWORD_2"',
                'value1: "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35"',
                'name: "TEST_PASSWORD_3"',
                'value: "PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"'
            ],
            start_line=5,
            target_index=5
        )
        raw_context = CodeSnippet(
            snippet=[
                '#\n',
                 '#\n',
                 'spec:\n',
                 '  - name: SOME_NAME\n',
                 '    value: some_value\n',
                 '    value: Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE\n',
                 '    name: TEST_PASSWORD_1\n',
                 '  - name1: TEST_PASSWORD_2\n',
                 '    value1: 1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35\n',
                 '    name: TEST_PASSWORD_3\n',
                 '    value: PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h\n'
            ],
            start_line=5,
            target_index=5
        )
        res = self.plugin.analyze_line(
            filename="test.yml",
            line='value: "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"',
            line_number=11,
            context=context,
            raw_context=raw_context
        )

        expected_secret_value = 'Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE'
        assert res
        po_secret = res.pop()
        assert expected_secret_value == po_secret.secret_value
        assert po_secret.is_multiline is True

    def test_keyword_in_value_pair_long_password(self):
        # first line is keyword, next line (underneath) is a long multiline password
        context = CodeSnippet(
            snippet=[
                'name: "TEST_PASSWORD_3"',
                'value: "PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"',
                'name: "TEST_PASSWORD_4"',
                'value: "emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z"',
                'name: "TEST_PASSWORD_LONG_1"',
                'value: "m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN"',
                'name: "TEST_PASSWORD_no_password"',
                'value: "RandomP@ssw0rd"'
            ],
            start_line=7,
            target_index=5
        )
        raw_context = CodeSnippet(
            snippet=[
                '  - name: TEST_PASSWORD_3\n',
                '    value: PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h\n',
                '  - name: TEST_PASSWORD_4\n',
                '    value: emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z\n',
                '  - name: TEST_PASSWORD_LONG_1\n',
                '    value: m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN\n',
                '  - name: TEST_PASSWORD_no_password\n',
                '    value: RandomP@ssw0rd\n'
            ],
            start_line=112,
            target_index=5
        )
        res = self.plugin.analyze_line(
            filename="test.yml",
            line='value: "Zmlyc3Rfc2VjcmV0MjIyMjIyX2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzI"',
            line_number=118,
            context=context,
            raw_context=raw_context
        )
        expected_secret_value = 'm9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN'
        assert res
        po_secret = res.pop()
        assert expected_secret_value == po_secret.secret_value
        assert po_secret.is_multiline is True

    def test_multiline_keyword_password_report(self):
        test_file_path = Path(__file__).parent / "yml_multiline/test-multiline-secrets.yml"

        report = Runner().run(
            root_folder=None, files=[str(test_file_path)], runner_filter=RunnerFilter(framework=['secrets'])
        )
        self.assertEqual(len(report.failed_checks), 5)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(report.passed_checks, [])
        self.assertEqual(report.skipped_checks, [])

    def test_non_multiline_pair_time_limit_creating_report(self):
        # given
        test_files = [str(Path(__file__).parent / "yml_multiline/pomerium_compose.yml")]
        runner = Runner()
        runner_filter = RunnerFilter(framework=['secrets'])

        # when
        start_time = time.time()
        report = runner.run(root_folder=None, files=test_files, runner_filter=runner_filter)
        end_time = time.time()

        # then
        assert end_time-start_time < 2  # assert the time limit is not too long for parsing long lines.
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks,
                                                                     ["CKV_SECRET_4", "CKV_SECRET_6", "CKV_SECRET_13"])
        self.assertEqual(len(interesting_failed_checks), 4)
        self.assertEqual(report.parsing_errors, [])
        self.assertEqual(report.passed_checks, [])
        self.assertEqual(report.skipped_checks, [])

    def test_regex_keyword_in_value(self):
        # the regex only finds the relevant part from the keyword that matches,
        # the whole keyword is not found by the current regex.

        examples = [
            # (line, keyword)
            (
                "        - name: TEST_PASSWORD_1\n",
                "PASSWORD",
            ),
            (
                "          name: TEST_PASSWORD_1\n",
                "PASSWORD",
            )
        ]

        keyword_value_regex_to_group = REGEX_VALUE_KEYWORD_BY_FILETYPE.get(FileType.YAML)
        value_regex, group_number = list(keyword_value_regex_to_group.items())[0]
        for line, secret in examples:
            match = value_regex.search(line).group(group_number)
            assert match == secret

    def test_regex_secret_in_value(self):
        examples = [
            # (line, secret)
            (
                "         - value: Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==\n",
                "Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==\n",
            ),
            (
                "           value: Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==\n",
                "Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==\n",
            ),
        ]

        secret_value_regex_to_group = REGEX_VALUE_SECRET_BY_FILETYPE.get(FileType.YAML)
        value_regex, group_number = list(secret_value_regex_to_group.items())[0]
        for line, secret in examples:
            match = value_regex.search(line).group(group_number)
            assert match == secret



import unittest

from checkov.terraform.checks.resource.gcp.GoogleCloudSqlBackupConfiguration import check
from checkov.common.models.enums import CheckResult


class GoogleCloudSqlDatabaseBackupConfiguration(unittest.TestCase):
    def test_failure(self):
        resource_conf = {"name": ["google_cluster"], "monitoring_service": ["none"]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        resource_conf = {
            "name": ["terraform-master"],
            "region": ["asia-northeasteast1"],
            "database_version": ["MYSQL_5_6"],
            "project": ["test-141901"],
            "settings": [
                {
                    "tier": ["db-f1-micro"],
                    "replication_type": ["SYNCHRONOUS"],
                    "backup_configuration": [{"enabled": [True], "start_time": ["17:00"]}],
                    "ip_configuration": [{"ipv4_enabled": [True]}],
                    "database_flags": [
                        {"name": ["slow_query_log", "character_set_server"], "value": ["on", "utf8mb4"]}
                    ],
                }
            ],
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)

    def test_replica_unknown(self):
        resource_conf = {"name": ["google_cluster"], "monitoring_service": ["none"], "master_instance_name": "foo"}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.UNKNOWN, scan_result)


if __name__ == "__main__":
    unittest.main()



import os
from unittest import mock

import responses

from checkov.common.sca.output import get_license_statuses, _get_request_input


def test_get_request_input():
    packages_input = [
        {"name": "docutils", "version": "0.15.2", "type": "python"},
        {"name": "github.com/apparentlymart/go-textseg/v12", "version": "v12.0.0", "lang": "go"},
        {"name": "ruby_package", "version": "9.9.9", "type": "ruby"},
        {"name": "ruby_package2", "version": "8.8.8", "type": "gem"},
        {"name": "empty_type_package", "version": "8.8.8", "type": ""},
        {"name": "invalid_type_package", "version": "8.8.8", "type": "bbbbb"}
    ]
    request_input = _get_request_input(packages_input)

    assert request_input == [
        {'name': 'docutils', 'version': '0.15.2', 'lang': 'python'},
        {'name': 'github.com/apparentlymart/go-textseg/v12', 'version': 'v12.0.0', 'lang': ''},
        {'name': 'ruby_package', 'version': '9.9.9', 'lang': 'ruby'},
        {'name': 'ruby_package2', 'version': '8.8.8', 'lang': 'ruby'},
        {'name': 'empty_type_package', 'version': '8.8.8', 'lang': ''},
        {'name': 'invalid_type_package', 'version': '8.8.8', 'lang': 'bbbbb'}
    ]


@responses.activate
def test_licenses_status(mock_bc_integration):
    packages_input = [
        {"name": "docutils", "version": "0.15.2", "lang": "python"},
        {"name": "github.com/apparentlymart/go-textseg/v12", "version": "v12.0.0", "lang": "go"}
    ]

    response_json = {
        "violations": [
            {
                "name": "github.com/apparentlymart/go-textseg/v12",
                "version": "v12.0.0",
                "license": "Apache-2.0",
                "policy": "BC_LIC_1",
                "status": "COMPLIANT"
            },
            {
                "name": "docutils",
                "version": "0.15.2",
                "license": "Apache-2.0",
                "policy": "BC_LIC_1",
                "status": "COMPLIANT"
            },
        ]
    }

    # given
    responses.add(
        method=responses.POST,
        url=mock_bc_integration.api_url + "/api/v1/vulnerabilities/packages/get-licenses-violations",
        json=response_json,
        status=200
    )

    license_statuses = get_license_statuses(packages_input)
    assert license_statuses == [
        {
            "package_name": "github.com/apparentlymart/go-textseg/v12",
            "package_version": "v12.0.0",
            "policy": "BC_LIC_1",
            "license": "Apache-2.0",
            "status": "COMPLIANT",
        },
        {
            "package_name": "docutils",
            "package_version": "0.15.2",
            "policy": "BC_LIC_1",
            "license": "Apache-2.0",
            "status": "COMPLIANT",
        },
    ]


@mock.patch.dict(os.environ, {"REQUEST_MAX_TRIES": "1", "SLEEP_BETWEEN_REQUEST_TRIES": "0.01"})
@responses.activate
def test_licenses_status_on_failure(mock_bc_integration):
    # given
    packages_input = [
        {"name": "docutils", "version": "0.15.2", "lang": "python"},
        {"name": "github.com/apparentlymart/go-textseg/v12", "version": "v12.0.0", "lang": "go"}
    ]

    responses.add(
        method=responses.POST,
        url=mock_bc_integration.api_url + "/api/v1/vulnerabilities/packages/get-licenses-violations",
        status=500
    )

    # when
    # we expect no failure here, in case of a http/connection error
    license_statuses = get_license_statuses(packages_input)

    # then
    assert len(license_statuses) == 0



import itertools
import os
import unittest
from pathlib import Path

import pytest

from checkov.cloudformation.runner import Runner
from checkov.common.checks_infra.checks_parser import GraphCheckParser
from checkov.common.checks_infra.registry import Registry
from checkov.runner_filter import RunnerFilter


class TestRunningGraphChecks(unittest.TestCase):

    @pytest.mark.skip("Graph checks have not been written yet for cloudformation")
    def test_runner(self):
        dir_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "resources")
        report = Runner().run(dir_path)
        assert any(
            check.check_id == "CKV2_AWS_24" for check in itertools.chain(report.failed_checks, report.passed_checks))
        assert any(
            check.check_id == "CKV2_AWS_25" for check in itertools.chain(report.failed_checks, report.passed_checks))
        assert any(
            check.check_id == "CKV2_AWS_26" for check in itertools.chain(report.failed_checks, report.passed_checks))

    @pytest.mark.skip("Graph checks have not been written yet for cloudformation")
    def test_runner_sam(self):
        # given
        test_dir_path = Path(__file__).parent.parent / "graph_builder/resources/sam"

        # when
        report = Runner().run(root_folder=str(test_dir_path), runner_filter=RunnerFilter(checks=["CKV2_AWS_26"]))

        # then
        summary = report.get_summary()

        passing_resources = {
            "AWS::Serverless::Function.Function1",
            "AWS::Serverless::Function.Function2",
        }

        passed_check_resources = {c.resource for c in report.passed_checks}

        self.assertEqual(summary["passed"], 2)
        self.assertEqual(summary["failed"], 0)
        self.assertEqual(summary["skipped"], 0)
        self.assertEqual(summary["parsing_errors"], 0)

        self.assertEqual(passing_resources, passed_check_resources)

    def test_jsonpath_policy(self):
        test_dir_path = Path(__file__).parent / "resources" / "jsonpath_policy"
        check_dir = Path(__file__).parent / "external_graph_checks"

        test_check_registry = Registry(
            checks_dir=f'{check_dir}',
            parser=GraphCheckParser()
        )

        # when
        report = Runner(external_registries=[test_check_registry]).run(root_folder=str(test_dir_path),
                              runner_filter=RunnerFilter(checks=["CKV2_CFN_JSONPATH_POLICY"]))

        # then
        summary = report.get_summary()

        passing_resources = {
            "AWS::MediaStore::Container.pass-str",
        }

        failing_resources = {
            "AWS::MediaStore::Container.fail-str",
            "AWS::MediaStore::Container.fail-dict",
        }

        passed_check_resources = {c.resource for c in report.passed_checks}
        failed_check_resources = {c.resource for c in report.failed_checks}


        self.assertEqual(summary["passed"], 1)
        self.assertEqual(summary["failed"], 2)
        self.assertEqual(summary["skipped"], 0)
        self.assertEqual(summary["parsing_errors"], 0)

        self.assertEqual(passing_resources, passed_check_resources)
        self.assertEqual(failing_resources, failed_check_resources)


    def test_complex_jsonpath_if_condition(self):
        test_dir_path = Path(__file__).parent / "resources" / "complex_jsonpath_if_condition"
        check_dir = Path(__file__).parent / "external_graph_checks"

        test_check_registry = Registry(
            checks_dir=f'{check_dir}',
            parser=GraphCheckParser()
        )

        # when
        report = Runner(
            external_registries=[test_check_registry]).\
            run(root_folder=str(test_dir_path),
                runner_filter=RunnerFilter(checks=["complex_jsonpath_if_condition"])
        )

        # then
        summary = report.get_summary()

        passing_resources = {
            "AWS::ECS::TaskDefinition.PassingExample",
        }

        failing_resources = {
            "AWS::ECS::TaskDefinition.FailingExample"
        }

        passed_check_resources = {c.resource for c in report.passed_checks}
        failed_check_resources = {c.resource for c in report.failed_checks}


        self.assertEqual(summary["passed"], 1)
        self.assertEqual(summary["failed"], 1)
        self.assertEqual(summary["skipped"], 0)
        self.assertEqual(summary["parsing_errors"], 0)

        self.assertEqual(passing_resources, passed_check_resources)
        self.assertEqual(failing_resources, failed_check_resources)

    def test_template_with_parameters_names_identical_to_default_values(self):
        test_dir_path = Path(__file__).parent / "resources" / \
                        "template_with_parameters_names_identical_to_default_values"
        check_dir = Path(__file__).parent / "external_graph_checks"

        test_check_registry = Registry(
            checks_dir=f'{check_dir}',
            parser=GraphCheckParser()
        )

        # when
        report = Runner(
            external_registries=[test_check_registry]).\
            run(root_folder=str(test_dir_path),
                runner_filter=RunnerFilter(checks=["CKV2_TEST_SIMPLE"])
        )

        # then
        summary = report.get_summary()

        passing_resources = {
            "AWS::ECS::TaskDefinition.Pass",
        }

        failing_resources = {
            "AWS::ECS::TaskDefinition.Fail"
        }

        passed_check_resources = {c.resource for c in report.passed_checks}
        failed_check_resources = {c.resource for c in report.failed_checks}


        self.assertEqual(summary["passed"], 1)
        self.assertEqual(summary["failed"], 1)
        self.assertEqual(summary["skipped"], 0)
        self.assertEqual(summary["parsing_errors"], 0)

        self.assertEqual(passing_resources, passed_check_resources)
        self.assertEqual(failing_resources, failed_check_resources)


if __name__ == '__main__':
    unittest.main()



import dis
import inspect
import os
import unittest
from collections import defaultdict
from pathlib import Path

from parameterized import parameterized_class

from checkov.common.bridgecrew.check_type import CheckType
from checkov.common.bridgecrew.severities import Severities, BcSeverities
from checkov.common.checks_infra.registry import get_graph_checks_registry
from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
from checkov.common.graph.db_connectors.rustworkx.rustworkx_db_connector import RustworkxConnector
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.kubernetes.checks.resource.base_spec_check import BaseK8Check
from checkov.runner_filter import RunnerFilter
from checkov.kubernetes.runner import Runner
from checkov.kubernetes.checks.resource.registry import registry

@parameterized_class([
   {"db_connector": NetworkxConnector},
   {"db_connector": RustworkxConnector}
])
class TestRunnerValid(unittest.TestCase):
    def setUp(self) -> None:
        self.orig_checks = registry.checks

    def test_registry_has_type(self):
        self.assertEqual(registry.report_type, CheckType.KUBERNETES)

    def test_runner_honors_enforcement_rules(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_dir_path = os.path.join(current_dir, "resources")

        external_checks = os.path.join(current_dir, '..', 'graph', 'checks', 'test_checks')

        runner = Runner(db_connector=self.db_connector())
        filter = RunnerFilter(framework=['kubernetes'], use_enforcement_rules=True)
        # this is not quite a true test, because the checks don't have severities. However, this shows that the check registry
        # passes the report type properly to RunnerFilter.should_run_check, and we have tests for that method
        filter.enforcement_rule_configs = {CheckType.KUBERNETES: Severities[BcSeverities.OFF]}
        # load the test graph checks because there are no k8s graph checks at the moment, but we need to test that the graph registry knows what type it is
        report = runner.run(root_folder=scan_dir_path, external_checks_dir=[external_checks],
                            runner_filter=filter)

        self.assertEqual(len(report.failed_checks), 0)
        self.assertEqual(len(report.passed_checks), 0)
        self.assertEqual(len(report.skipped_checks), 0)
        self.assertEqual(len(report.parsing_errors), 0)

    def test_record_relative_path_with_relative_dir(self):

        # test whether the record's repo_file_path is correct, relative to the CWD (with a / at the start).

        # this is just constructing the scan dir as normal
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_dir_path = os.path.join(current_dir, "resources")

        # this is the relative path to the directory to scan (what would actually get passed to the -d arg)
        dir_rel_path = os.path.relpath(scan_dir_path).replace('\\', '/')

        runner = Runner(db_connector=self.db_connector())
        checks_allowlist = ['CKV_K8S_21']
        report = runner.run(root_folder=dir_rel_path, external_checks_dir=None,
                            runner_filter=RunnerFilter(framework=['kubernetes'], checks=checks_allowlist))

        all_checks = report.failed_checks + report.passed_checks
        self.assertGreater(len(all_checks), 0)  # ensure that the assertions below are going to do something
        for record in all_checks:
            self.assertEqual(record.repo_file_path, f'/{dir_rel_path}{record.file_path}')

    def test_record_relative_path_with_abs_dir(self):

        # test whether the record's repo_file_path is correct, relative to the CWD (with a / at the start).

        # this is just constructing the scan dir as normal
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_dir_path = os.path.join(current_dir, "resources")

        dir_rel_path = os.path.relpath(scan_dir_path).replace('\\', '/')

        dir_abs_path = os.path.abspath(scan_dir_path)

        runner = Runner(db_connector=self.db_connector())
        checks_allowlist = ['CKV_K8S_21']
        report = runner.run(root_folder=dir_abs_path, external_checks_dir=None,
                            runner_filter=RunnerFilter(framework=['kubernetes'], checks=checks_allowlist))

        all_checks = report.failed_checks + report.passed_checks
        self.assertGreater(len(all_checks), 0)  # ensure that the assertions below are going to do something
        for record in all_checks:
            # no need to join with a '/' because the CFN runner adds it to the start of the file path
            self.assertEqual(record.repo_file_path, f'/{dir_rel_path}{record.file_path}')

    def test_record_relative_path_with_relative_file(self):

        # test whether the record's repo_file_path is correct, relative to the CWD (with a / at the start).

        # this is just constructing the scan dir as normal
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_file_path = os.path.join(current_dir, "resources", "example.yaml")

        # this is the relative path to the file to scan (what would actually get passed to the -f arg)
        file_rel_path = os.path.relpath(scan_file_path)

        runner = Runner(db_connector=self.db_connector())
        checks_allowlist = ['CKV_K8S_21']
        report = runner.run(root_folder=None, external_checks_dir=None, files=[file_rel_path],
                            runner_filter=RunnerFilter(framework='kubernetes', checks=checks_allowlist))

        all_checks = report.failed_checks + report.passed_checks
        self.assertGreater(len(all_checks), 0)  # ensure that the assertions below are going to do something
        for record in all_checks:
            # no need to join with a '/' because the CFN runner adds it to the start of the file path
            self.assertEqual(record.repo_file_path, f'/{file_rel_path}')

    def test_record_relative_path_with_abs_file(self):

        # test whether the record's repo_file_path is correct, relative to the CWD (with a / at the start).

        # this is just constructing the scan dir as normal
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_file_path = os.path.join(current_dir, "resources", "example.yaml")

        file_rel_path = os.path.relpath(scan_file_path)
        file_abs_path = os.path.abspath(scan_file_path)

        runner = Runner(db_connector=self.db_connector())
        checks_allowlist = ['CKV_K8S_21']
        report = runner.run(root_folder=None, external_checks_dir=None, files=[file_abs_path],
                            runner_filter=RunnerFilter(framework='kubernetes', checks=checks_allowlist))

        all_checks = report.failed_checks + report.passed_checks
        self.assertGreater(len(all_checks), 0)  # ensure that the assertions below are going to do something
        for record in all_checks:
            # no need to join with a '/' because the CFN runner adds it to the start of the file path
            self.assertEqual(record.repo_file_path, f'/{file_rel_path}')

    def test_list_metadata_annotations(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_file_path = os.path.join(current_dir, "list_annotation", "example.yaml")
        file_rel_path = os.path.relpath(scan_file_path)
        runner = Runner(db_connector=self.db_connector())
        try:
            runner.run(root_folder=None, external_checks_dir=None, files=[file_rel_path],
                                runner_filter=RunnerFilter(framework='kubernetes'))
        except Exception:
            self.assertTrue(False, "Could not run K8 runner on configuration")

    def test_wrong_check_imports(self):
        wrong_imports = ["arm", "cloudformation", "dockerfile", "helm", "serverless", "terraform", "kustomize"]
        check_imports = []

        checks_path = Path(inspect.getfile(Runner)).parent.joinpath("checks")
        for file in checks_path.rglob("*.py"):
            with file.open() as f:
                instructions = dis.get_instructions(f.read())
                import_names = [instr.argval for instr in instructions if "IMPORT_NAME" == instr.opname]

                for import_name in import_names:
                    wrong_import = next((import_name for x in wrong_imports if x in import_name), None)
                    if wrong_import:
                        check_imports.append({file.name: wrong_import})

        assert len(check_imports) == 0, f"Wrong imports were added: {check_imports}"

    def test_parse_with_empty_blocks(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        scan_file_path = os.path.join(current_dir, "resources", "example_multiple.yaml")
        file_rel_path = os.path.relpath(scan_file_path)
        runner = Runner(db_connector=self.db_connector())
        try:
            report = runner.run(root_folder=None, external_checks_dir=None, files=[file_rel_path],
                       runner_filter=RunnerFilter(framework='kubernetes'))
            # just check that something was parsed and scanned
            self.assertGreater(len(report.failed_checks) + len(report.passed_checks), 0)
        except Exception:
            self.assertTrue(False, "Could not run K8 runner on configuration")

    def test_record_includes_severity(self):
        custom_check_id = "CKV_MY_CUSTOM_CHECK"

        registry.checks = defaultdict(list)

        class AnyFailingCheck(BaseK8Check):
            def __init__(self, *_, **__) -> None:
                super().__init__(
                    "this should fail",
                    custom_check_id,
                    [CheckCategories.KUBERNETES],
                    ["Service"]
                )

            def scan_spec_conf(self, conf):
                return CheckResult.FAILED

        check = AnyFailingCheck()
        check.severity = Severities[BcSeverities.LOW]
        scan_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "resources", "example.yaml")

        report = Runner(db_connector=self.db_connector()).run(
            None,
            files=[scan_file_path],
            runner_filter=RunnerFilter(framework=['kubernetes'], checks=[custom_check_id])
        )

        self.assertEqual(report.failed_checks[0].severity, Severities[BcSeverities.LOW])

    def test_record_check_severity(self):
        custom_check_id = "CKV_MY_CUSTOM_CHECK"

        registry.checks = defaultdict(list)

        class AnyFailingCheck(BaseK8Check):
            def __init__(self, *_, **__) -> None:
                super().__init__(
                    "this should fail",
                    custom_check_id,
                    [CheckCategories.KUBERNETES],
                    ["Service"]
                )

            def scan_spec_conf(self, conf):
                return CheckResult.FAILED

        check = AnyFailingCheck()
        check.severity = Severities[BcSeverities.MEDIUM]
        scan_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "resources", "example.yaml")

        report = Runner(db_connector=self.db_connector()).run(
            None,
            files=[scan_file_path],
            runner_filter=RunnerFilter(framework=['kubernetes'], checks=['LOW'])
        )

        all_checks = report.failed_checks + report.passed_checks
        self.assertTrue(any(c.check_id == custom_check_id for c in all_checks))

    def test_record_check_severity_omit(self):
        custom_check_id = "CKV_MY_CUSTOM_CHECK"

        registry.checks = defaultdict(list)

        class AnyFailingCheck(BaseK8Check):
            def __init__(self, *_, **__) -> None:
                super().__init__(
                    "this should fail",
                    custom_check_id,
                    [CheckCategories.KUBERNETES],
                    ["Service"]
                )

            def scan_spec_conf(self, conf):
                return CheckResult.FAILED

        check = AnyFailingCheck()
        check.severity = Severities[BcSeverities.MEDIUM]
        scan_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "resources", "example.yaml")

        report = Runner(db_connector=self.db_connector()).run(
            None,
            files=[scan_file_path],
            runner_filter=RunnerFilter(framework=['kubernetes'], checks=['HIGH'])
        )

        all_checks = report.failed_checks + report.passed_checks
        self.assertFalse(any(c.check_id == custom_check_id for c in all_checks))

    def test_record_check_skip_severity(self):
        custom_check_id = "CKV_MY_CUSTOM_CHECK"

        registry.checks = defaultdict(list)

        class AnyFailingCheck(BaseK8Check):
            def __init__(self, *_, **__) -> None:
                super().__init__(
                    "this should fail",
                    custom_check_id,
                    [CheckCategories.KUBERNETES],
                    ["Service"]
                )

            def scan_spec_conf(self, conf):
                return CheckResult.FAILED

        check = AnyFailingCheck()
        check.severity = Severities[BcSeverities.HIGH]
        scan_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "resources", "example.yaml")

        report = Runner(db_connector=self.db_connector()).run(
            None,
            files=[scan_file_path],
            runner_filter=RunnerFilter(framework=['kubernetes'], skip_checks=['MEDIUM'])
        )

        all_checks = report.failed_checks + report.passed_checks
        self.assertTrue(any(c.check_id == custom_check_id for c in all_checks))

    def test_record_check_skip_severity_omit(self):
        custom_check_id = "CKV_MY_CUSTOM_CHECK"

        registry.checks = defaultdict(list)

        class AnyFailingCheck(BaseK8Check):
            def __init__(self, *_, **__) -> None:
                super().__init__(
                    "this should fail",
                    custom_check_id,
                    [CheckCategories.KUBERNETES],
                    ["Service"]
                )

            def scan_spec_conf(self, conf):
                return CheckResult.FAILED

        check = AnyFailingCheck()
        check.severity = Severities[BcSeverities.LOW]
        scan_file_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "resources", "example.yaml")

        report = Runner(db_connector=self.db_connector()).run(
            None,
            files=[scan_file_path],
            runner_filter=RunnerFilter(framework=['kubernetes'], skip_checks=['MEDIUM'])
        )

        all_checks = report.failed_checks + report.passed_checks
        self.assertFalse(any(c.check_id == custom_check_id for c in all_checks))

    def tearDown(self):
        registry.checks = self.orig_checks
        get_graph_checks_registry("kubernetes").checks = []


if __name__ == '__main__':
    unittest.main()



from aws_cdk import core
from aws_cdk import aws_amazonmq as amazonmq

class AmazonMQStack(core.Stack):

    def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
        super().__init__(scope, id, **kwargs)

        # Create an Amazon MQ broker with PubliclyAccessible set to false
        amazonmq_broker = amazonmq.CfnBroker(
            self,
            "MyAmazonMQBroker",
            broker_name="my-amazon-mq-broker",
            engine_type="ACTIVEMQ",
            host_instance_type="mq.t2.micro",
            publicly_accessible=True,  # Set PubliclyAccessible to false
        )

app = core.App()
AmazonMQStack(app, "AmazonMQStack")
app.synth()



import pickle
import unittest
from pathlib import Path

from checkov.github_actions.runner import Runner
from checkov.github_actions.utils import build_gha_definitions_context
from checkov.runner_filter import RunnerFilter


def test_runner_with_existing_graph():

    def mock_graph():
        with open(str(Path(__file__).parent / 'resources/graph.pkl'), 'rb') as inp:
            graph = pickle.load(inp)
            return graph

    # given
    file_path = Path(__file__).parent / "gha/.github/workflows/failed.yaml"
    file_dir = [str(file_path)]
    checks = ["CKV2_GHA_1"]
    definitions = {'/Users/mamelchenko/development/checkov/tests/github_actions/gha/.github/workflows/failed.yaml': {'name': 'read-only', 'on': {'pull_request': {'types': ['opened', 'synchronize', 'labeled', 'unlabeled'], '__startline__': 5, '__endline__': 7}, '__startline__': 4, '__endline__': 7}, 'permissions': 'write-all', 'jobs': {'example': {'runs-on': 'ubuntu-latest', 'steps': [{'uses': 'actions/checkout@12345678', '__startline__': 13, '__endline__': 14}, {'run': 'echo "working hard"\n', '__startline__': 14, '__endline__': 16}], '__startline__': 11, '__endline__': 16}, '__startline__': 10, '__endline__': 16}, '__startline__': 1, '__endline__': 16}}
    definitions_raw = {'/Users/mamelchenko/development/checkov/tests/github_actions/gha/.github/workflows/failed.yaml': [(1, 'name: read-only\n'), (2, '\n'), (3, 'on:\n'), (4, '  pull_request:\n'), (5, '    types: [ opened, synchronize, labeled, unlabeled ]\n'), (6, '\n'), (7, 'permissions: write-all\n'), (8, '\n'), (9, 'jobs:\n'), (10, '  example:\n'), (11, '    runs-on: ubuntu-latest\n'), (12, '    steps:\n'), (13, '      - uses: actions/checkout@12345678\n'), (14, '      - run: |\n'), (15, '          echo "working hard"\n')]}
    context = build_gha_definitions_context(definitions=definitions, definitions_raw=definitions_raw)

    graph_runner = Runner()
    graph_runner.graph_manager.get_reader_endpoint = mock_graph
    graph_runner.set_external_data(definitions=definitions, context=context, breadcrumbs=None)
    graph_runner.set_raw_definitions(definitions_raw=definitions_raw)
    # when
    report = graph_runner.run(files=file_dir, runner_filter=RunnerFilter(framework=["github_actions"], checks=checks))

    # then
    assert len(report.failed_checks) == 1
    assert len(report.passed_checks) == 0
    assert len(report.skipped_checks) == 0
    assert len(report.parsing_errors) == 0


if __name__ == "__main__":
    unittest.main()



import os
import unittest
from pathlib import Path
from typing import Any, Dict, List

from checkov.common.bridgecrew.platform_integration import bc_integration
from checkov.runner_filter import RunnerFilter
from checkov.secrets.plugins.load_detectors import modify_secrets_policy_to_detectors, get_runnable_plugins
from checkov.secrets.runner import Runner
from tests.secrets.utils_for_test import _filter_reports_for_incident_ids


class TestLoadDetectors(unittest.TestCase):

    def test_get_runnable_plugins(self) -> None:
        policies_list: List[Dict[str, Any]] = [
            {
                "incidentId": "incident1",
                "category": "Secrets",
                "code": "definition:\n  cond_type: secrets\n  value:\n  - one_value\n",
                "title": "incident1",
            },
            {
                "incidentId": "incident2",
                "category": "Secrets",
                "code": "definition:\n  cond_type: secrets\n  value:\n  - H4sIAPmp12MC/8tIzcnJBwCGphA2BQAAAA==\n  is_runnable: true\n",
                "title": "incident2",
            },
            {
                "incidentId": "incident3",
                "category": "Secrets",
                "code": "",
                "title": "incident3",
            },
            {
                "incidentId": "incident4",
                "category": "Secrets",
                "code": "bad_code",
                "title": "incident4",
            },
            {
                "incidentId": "incident5",
                "category": "Secrets",
                "code": "definition:\n  cond_type: secrets\n  value:\n  - invalid\n  is_runnable: true\n",
                "title": "incident5",
            },
        ]
        runnables = get_runnable_plugins(policies_list)
        assert len(runnables) == 1
        assert runnables["incident2"] == 'hello'


    def test_modify_secrets_policy_to_detectors(self) -> None:
        policies_list: List[Dict[str, Any]] = [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes": [
                    "aws_instance"
                ],
                "provider": "AWS",
                "remediationIds": [],
                "conditionQuery": {
                    "value": [],
                    "cond_type": "secrets"
                },
                "customerName": "lshind",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "frameworks": [
                    "CloudFormation",
                    "Terraform"
                ],
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["abcdefg"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": [
                        "1234567"
                    ],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]
        detector_obj = modify_secrets_policy_to_detectors(policies_list)
        detectors_result: List[Dict[str, Any]] = [{
            "Name": "test1",
            "Check_ID": "test1",
            "Regex": "abcdefg"
        },
            {
                "Name": "test2",
                "Check_ID": "test2",
                "Regex": "1234567"
            }]
        detector_obj.sort(key=lambda detector: detector['Check_ID'])
        detectors_result.sort(key=lambda detector: detector['Check_ID'])  # type: ignore
        assert all(
            True for x in range(0, len(detector_obj)) if detector_obj[x]['Check_ID'] == detectors_result[x]['Check_ID'])
        assert len(detectors_result) == len(detector_obj)

    def test_custom_regex_detector(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test1",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?:^|\W)HANA(?:$|\W)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": None,
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?:^|\W)LIR(?:$|\W)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": None,
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 3)

    def test_non_entropy_take_precedence_over_entropy(self):
        # given: File with entropy secret and custom secret
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/custom_and_entropy"
        check_id = 'test1'
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": check_id,
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": check_id,
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ['test_pass =\s*"(.*?)"'],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": None,
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()

        # when: Running the secrets runner on the file
        report = runner.run(root_folder=valid_dir_path, runner_filter=RunnerFilter(framework=['secrets'], enable_secret_scan_all_files=True))

        # then: Validating that the non-entropy is the one.
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1"])
        self.assertEqual(len(interesting_failed_checks), 1)
        self.assertEqual(interesting_failed_checks[0].check_id, check_id)

    def test_custom_regex_detector_value_str(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test1",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?:^|\W)HANA(?:$|\W)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": None,
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?:^|\W)LIR(?:$|\W)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": None,
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 3)

    def test_custom_regex_detector_in_custom_limit_characters(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?i)(?:test)(?:[0-9a-z\\-_\\t .]{0,20})(?:[\\s|']|[\\s|\"]){0,3}(?:=|>|:=|\\|\\|:|<=|=>|:)(?:'|\\\"|\\s|=|\\x60){0,5}([a-z0-9]{24})(?:['|\\\"|\\n|\\r|\\s|\\x60|;]|$)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 1)

    def test_custom_regex_detector_out_custom_limit_characters(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?i)(?:out)(?:[0-9a-z\\-_\\t .]{0,20})(?:[\\s|']|[\\s|\"]){0,3}(?:=|>|:=|\\|\\|:|<=|=>|:)(?:'|\\\"|\\s|=|\\x60){0,5}([a-z0-9]{24})(?:['|\\\"|\\n|\\r|\\s|\\x60|;]|$)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 0)

    def test_custom_regex_detector_skip_long_line(self):
        #  given
        valid_dir_path = Path(__file__).parent / "long_line_custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["\w{20}"],  # this would definitely get a result, but should not, because of the line length
                    "cond_type": "secrets"
                },
                "resourceTypes": [],
                "provider": "AWS",
                "remediationIds": [],
                "customerName": "test2",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}

        # when
        report = Runner().run(
            root_folder=str(valid_dir_path),
            runner_filter=RunnerFilter(
                framework=["secrets"],
                enable_secret_scan_all_files=True
            )
        )

        # then
        self.assertEqual(len(report.failed_checks), 0)

    def test_modify_secrets_policy_to_multiline_detectors(self) -> None:
        policies_list: List[Dict[str, Any]] = [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes": [
                    "aws_instance"
                ],
                "provider": "AWS",
                "remediationIds": [],
                "customerName": "lshind",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  value:\n  - '{[\\s\\S]*}'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "frameworks": [
                    "CloudFormation",
                    "Terraform"
                ],
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  multiline: true\n  value:\n  - '{[\\s\\S]*paz*}'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test3",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": [
                        "1234567"
                    ],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test3",
                "isCustom": True,
                "code": "",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]
        detector_obj = modify_secrets_policy_to_detectors(policies_list)
        detectors_expected_result: List[Dict[str, Any]] = [
            {"Name": "test1", "Check_ID": "test1", "Regex": "{[\\s\\S]*}", "isMultiline": False},
            {"Name": "test2", "Check_ID": "test2", "Regex": "{[\\s\\S]*paz*}", "isMultiline": True},
            {"Name": "test3", "Check_ID": "test3", "Regex": "1234567", "isMultiline": False}
        ]
        detector_obj.sort(key=lambda detector: detector['Check_ID'])
        detectors_expected_result.sort(key=lambda detector: detector['Check_ID'])  # type: ignore
        assert all(
            True for x in range(0, len(detector_obj)) if
            detector_obj[x]['Check_ID'] == detectors_expected_result[x]['Check_ID'] and
            detector_obj[x]['isMultiline'] == detectors_expected_result[x]['isMultiline'])
        assert len(detectors_expected_result) == len(detector_obj)

    def test_custom_multiline_regex_detector(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/multiline_custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test1",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  multiline: true\n  supported_files:\n  - .mine\n  value:\n  - '[\\s\\S]*HANA*'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "conditionQuery": {
                    "value": ["(?:^|\W)LIR(?:$|\W)"],
                    "cond_type": "secrets"
                },
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": None,
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(
                                framework=['secrets'],
                                enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 3)

    def test_custom_multiline_regex_detector_only_scan_file(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/multiline_custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test1",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  multiline: true\n  supported_files:\n  - .mine\n  value:\n  - '[\\s\\S]*HANA*'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  multiline: true\n  supported_files:\n  - .mine\n  value:\n  - '[\\s\\S]*LIR*'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 2)

    def test_custom_multiline_regex_detector_only_supported_files(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/multiline_custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test1",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  multiline: true\n  supported_files:\n  - .mine\n  value:\n  - '[\\s\\S]*HANA*'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            },
            {
                "incidentId": "test2",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test2",
                "guideline": "test2",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test2",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  multiline: true\n  value:\n  - '[\\s\\S]*LIR*'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1", "test2"])
        self.assertEqual(len(interesting_failed_checks), 1)

    def test_prerun_singleline_regex_detector(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        valid_dir_path = current_dir + "/multiline_custom_regex_detector"
        bc_integration.customer_run_config_response = {"secretsPolicies": [
            {
                "incidentId": "test1",
                "category": "Secrets",
                "severity": "MEDIUM",
                "incidentType": "Violation",
                "title": "test1",
                "guideline": "test",
                "laceworkViolationId": None,
                "prowlerCheckId": None,
                "checkovCheckId": None,
                "resourceTypes":
                    [
                        "aws_instance"
                    ],
                "provider": "AWS",
                "remediationIds":
                    [],
                "customerName": "test1",
                "isCustom": True,
                "code": "definition:\n  cond_type: secrets\n  prerun:\n  - (?i)(?:ACCESS)\n  supported_files:\n  - .mine\n  value:\n  - 'AWS_ACCESS_KEY_ID'",
                "descriptiveTitle": None,
                "constructiveTitle": None,
                "pcPolicyId": None,
                "additionalPcPolicyIds": None,
                "pcSeverity": None,
                "sourceIncidentId": None
            }
        ]}
        runner = Runner()
        report = runner.run(root_folder=valid_dir_path,
                            runner_filter=RunnerFilter(framework=['secrets'],
                                                       enable_secret_scan_all_files=True))
        interesting_failed_checks = _filter_reports_for_incident_ids(report.failed_checks, ["test1"])
        self.assertEqual(len(interesting_failed_checks), 1)



from pathlib import Path

from checkov.bicep.graph_manager import BicepGraphManager
from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector


def test_render_parameter():
    # given
    test_dir = Path(__file__).parent / "examples/parameter"
    graph_manager = BicepGraphManager(db_connector=NetworkxConnector())

    # when
    local_graph, _ = graph_manager.build_graph_from_source_directory(source_dir=str(test_dir), render_variables=True)

    # then
    vertex = local_graph.vertices[local_graph.vertices_by_name["vm"]]

    assert vertex.config["config"] == {
        "name": "example-vm",
        "location": "location",
        "properties": {
            "networkProfile": {
                "networkInterfaces": [{"id": "example-id"}]
            },
            "osProfile": {
                "linuxConfiguration": {
                    "ssh": {
                        "publicKeys": [
                            {"keyData": "key-data-1", "path": "path-1"},
                            {"keyData": "key-data-2", "path": "path-2"},
                            {"keyData": "key-data-3", "path": "path-3"},
                            {"keyData": {
                                "operator": {
                                    "type": "property_accessor",
                                    "operands": {
                                        "operand_1": {"keyData": "key-data-4", "path": {"name": "path-4"}},
                                        "operand_2": "keyData"
                                    }
                                }
                            },
                             "path": {
                                 "operator": {
                                     "type": "property_accessor",
                                     "operands": {
                                         "operand_1": {"keyData": "key-data-4", "path": {"name": "path-4"}},
                                         "operand_2": {
                                             "operator": {
                                                 "type": "property_accessor",
                                                 "operands": {"operand_1": "path", "operand_2": "name"}
                                             }
                                         }
                                     }
                                 }
                             }}
                        ]
                    }
                }
            },
            "storageProfile": {
                "imageReference": {"publisher": "MicrosoftWindowsServer"}
            }
        },
        "tags": {
            "displayName": "Container Registry",
            "'container.registry.name'": "exmaple-acr",
            "'container.registry'": {"name": "exmaple-nested-acr"},
        },
    }


def test_render_variable():
    # given
    test_dir = Path(__file__).parent / "examples/variable"
    graph_manager = BicepGraphManager(db_connector=NetworkxConnector())

    # when
    local_graph, _ = graph_manager.build_graph_from_source_directory(source_dir=str(test_dir), render_variables=True)

    # then
    vertex = local_graph.vertices[local_graph.vertices_by_name["vm"]]

    assert vertex.config["config"] == {
        "name": "example-vm",
        "location": "westeurope",
        "properties": {
            "networkProfile": {
                "networkInterfaces": [
                    {"id": "example-id"}
                ]
            },
            "osProfile": {
                "linuxConfiguration": {
                    "ssh": {
                        "publicKeys": [
                            {"keyData": "key-data-1", "path": "path-1"},
                            {"keyData": "key-data-2", "path": "path-2"},
                            {"keyData": "key-data-3", "path": "path-3"},
                            {
                                "keyData": {
                                    "operator": {
                                        "type": "property_accessor",
                                        "operands": {
                                            "operand_1": {
                                                "keyData": "key-data-4",
                                                "path": {"name": "path-4"}
                                            },
                                            "operand_2": "keyData"
                                        }
                                    }
                                },
                                "path": {
                                    "operator": {
                                        "type": "property_accessor",
                                        "operands": {
                                            "operand_1": {
                                                "keyData": "key-data-4",
                                                "path": {"name": "path-4"}
                                            },
                                            "operand_2": {
                                                "operator": {
                                                    "type": "property_accessor",
                                                    "operands": {
                                                        "operand_1": "path",
                                                        "operand_2": "name"
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        ]
                    }
                }
            },
            "storageProfile": {
                "imageReference": {
                    "publisher": "MicrosoftWindowsServer"
                }
            }
        },
        "tags": {
            "displayName": "Container Registry",
            "'container.registry.name'": "exmaple-acr",
            "'container.registry'": {"name": "exmaple-nested-acr"},
        },
    }


def test_render_mixed():
    # given
    test_dir = Path(__file__).parent / "examples/mixed"
    graph_manager = BicepGraphManager(db_connector=NetworkxConnector())

    # when
    local_graph, _ = graph_manager.build_graph_from_source_directory(source_dir=str(test_dir), render_variables=True)

    # then
    vertex = local_graph.vertices[local_graph.vertices_by_name["vm"]]

    assert vertex.config["config"] == {
        "name": "example-vm",
        "location": "location",
        "properties": {
            "networkProfile": {
                "networkInterfaces": [
                    {"id": "example-id"}
                ]
            },
            "osProfile": {
                "linuxConfiguration": {
                    "ssh": {
                        "publicKeys": [
                            {"keyData": "key-data-1", "path": "path-1"},
                            {"keyData": "key-data-2", "path": "path-2"},
                            {"keyData": "keyData3", "path": "path-3"},
                            {
                                "keyData": {
                                    "operator": {
                                        "type": "property_accessor",
                                        "operands": {
                                            "operand_1": {
                                                "keyData": "key-data-4",
                                                "path": {
                                                    "name": {
                                                        "operator": {
                                                            "type": "property_accessor",
                                                            "operands": {
                                                                "operand_1": {
                                                                    "keyData": "key-data-2",
                                                                    "path": "path-2"
                                                                },
                                                                "operand_2": "path"
                                                            }
                                                        }
                                                    }
                                                }
                                            },
                                            "operand_2": "keyData"
                                        }
                                    }
                                },
                                "path": {
                                    "operator": {
                                        "type": "property_accessor",
                                        "operands": {
                                            "operand_1": {
                                                "keyData": "key-data-4",
                                                "path": {
                                                    "name": {
                                                        "operator": {
                                                            "type": "property_accessor",
                                                            "operands": {
                                                                "operand_1": {
                                                                    "keyData": "key-data-2",
                                                                    "path": "path-2"
                                                                },
                                                                "operand_2": "path"
                                                            }
                                                        }
                                                    }
                                                }
                                            },
                                            "operand_2": {
                                                "operator": {
                                                    "type": "property_accessor",
                                                    "operands": {
                                                        "operand_1": "path",
                                                        "operand_2": "name"
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        ]
                    }
                }
            },
            "storageProfile": {
                "imageReference": {
                    "publisher": "publisher"
                }
            }
        },
        "tags": {
            "displayName": "Container Registry",
            "'container.registry.name'": "acrName",
            "'container.registry'": {"name": "acrNestedName"},
        },
    }



import os
import unittest
from json import JSONDecodeError
from pathlib import Path

from checkov.common.parsers.json import load
from checkov.cloudformation.runner import Runner
from checkov.runner_filter import RunnerFilter


class TestCfnJson(unittest.TestCase):

    def test_successful_parsing(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))

        test_files = f'{current_dir}/success.json'
        cfn = load(test_files)
        self.assertEqual(cfn[0]['AWSTemplateFormatVersion'], '2010-09-09')
        Runner().run(None, files=[test_files], runner_filter=RunnerFilter())

    def test_fail_parsing(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))

        test_files = current_dir + "/fail.json"
        self.assertRaises(JSONDecodeError, load, test_files)

    def test_skip_tf_plan_file(self):
        # given
        test_file = Path(__file__).parent / "tfplan.json"

        # when
        report = Runner().run(None, files=[str(test_file)], runner_filter=RunnerFilter())

        # then
        self.assertEqual(0, len(report.parsing_errors))
        
    def test_triple_quotes_string(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))

        test_files = f'{current_dir}/success_triple_quotes_string.json'
        cfn = load(test_files)
        self.assertEqual(cfn[0]['Metadata']['AWS::CloudFormation::Interface']['ParameterLabels']['NewTrailLogFilePrefix']['default'], 'Log file prefix\n hello')
        Runner().run(None, files=[test_files], runner_filter=RunnerFilter())


if __name__ == '__main__':
    unittest.main()



import os
import unittest

from checkov.terraform.module_loading.loaders.local_path_loader import loader
from checkov.terraform.module_loading.module_params import ModuleParams


class TestLocalPathLoader(unittest.TestCase):
    def test_child_dir(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        module_params = ModuleParams(current_dir, current_dir, "./resources", None, "", "")
        content = loader.load(module_params)
        assert content.loaded()
        assert content.path() == os.path.join(current_dir, "resources")

    def test_unhandled_source(self):
        module_params = ModuleParams("current_dir", "current_dir", "hashicorp/consul/aws", None, "", "")
        content = loader.load(module_params)
        assert not content.loaded()

    def test_bad_source(self):
        current_dir = os.path.dirname(os.path.realpath(__file__))
        with self.assertRaises(FileNotFoundError):
            module_params = ModuleParams(current_dir, current_dir, "./path_that_doesnt_exist", None, '', '')
            loader.load(module_params)

    def test_absolute_path(self):
        # Generate absolute path dynamically so test is OS agnostic
        current_dir = os.path.dirname(os.path.realpath(__file__))
        target_dir = os.path.join(current_dir, "resources")
        module_params = ModuleParams(current_dir, current_dir, target_dir, None, '', '')
        content = loader.load(module_params)
        assert content.loaded()
        assert content.path() == os.path.join(current_dir, "resources")
